@@ -25,8 +25,9 @@ HOSTNAME = 'freedombox'
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
 
-class Application(object):
+class Application:
     """Command line application to build FreedomBox images."""
+
     def __init__(self):
         """Initialize object."""
         self.arguments = None
