@@ -18,25 +18,26 @@ BASE_PACKAGES = [
 logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
 
-class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
+class ImageBuilder:  # pylint: disable=too-many-instance-attributes
     """Base for all image builders."""
-    architecture = None
-    machine = 'all'
-    free = True
+    architecture: str | None = None
+    machine: str = 'all'
+    include_non_free_firmware: bool = False
+    include_contrib: bool = False
 
-    builder_backend = 'internal'
-    partition_table_type = 'msdos'
-    root_filesystem_type = 'btrfs'
-    boot_filesystem_type = None
-    boot_size = None
-    efi_filesystem_type = None
-    efi_size = None
-    firmware_filesystem_type = None
-    firmware_size = None
-    kernel_flavor = 'default'
-    debootstrap_variant = None
+    builder_backend: str = 'internal'
+    partition_table_type: str = 'msdos'
+    root_filesystem_type: str = 'btrfs'
+    boot_filesystem_type: str | None = None
+    boot_size: str | None = None
+    efi_filesystem_type: str | None = None
+    efi_size: str | None = None
+    firmware_filesystem_type: str | None = None
+    firmware_size: str | None = None
+    kernel_flavor: str = 'default'
+    debootstrap_variant: str | None = None
 
-    extra_storage_size = '1000M'
+    extra_storage_size: str = '1000M'
 
     @classmethod
     def get_target_name(cls):
@@ -74,12 +75,20 @@ class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
         self.image_file = os.path.join(self.arguments.build_dir,
                                        self._get_image_base_name() + '.img')
 
+    @property
+    def image_size(self):
+        """Return the size of the image to create based on CLI arguments."""
+        return self.arguments.image_size
+
     @property
     def release_components(self):
         """Return the Debian release components to use for the build."""
         components = ['main']
-        if not self.free:
-            components += ['contrib', 'non-free-firmware', 'non-free']
+        if self.include_non_free_firmware:
+            components.append('non-free-firmware')
+
+        if self.include_contrib:
+            components.append('contrib')
 
         if self.arguments.release_component:
             for component in self.arguments.release_component:
