@@ -9,6 +9,7 @@ isort:skip_file
 from . import a20_olinuxino_lime2
 from . import a20_olinuxino_lime
 from . import a20_olinuxino_micro
+from . import a20_olinuxino_micro_emmc
 from . import amd64
 from . import arm
 from . import arm64
@@ -17,14 +18,12 @@ from . import banana_pro
 from . import beaglebone
 from . import cubieboard2
 from . import cubietruck
-from . import i386
 from . import lamobo_r1
 from . import orange_pi_zero
 from . import pcduino3
 from . import pine64_plus
 from . import pine64_lts
 from . import qemu_amd64
-from . import qemu_i386
 from . import raspberry_pi_2
 from . import raspberry_pi_3
 from . import raspberry_pi_3_b_plus
@@ -32,4 +31,3 @@ from . import raspberry_pi_64bit
 from . import raspberry_pi_with_uboot
 from . import vagrant
 from . import virtualbox_amd64
-from . import virtualbox_i386
