@@ -8,6 +8,6 @@ from .a64 import A64ImageBuilder
 
 class Pine64LTSImageBuilder(A64ImageBuilder):
     """Image builder for Pine64 LTS target."""
-    machine = 'pine64-lts'
-    flash_kernel_name = 'Pine64 LTS'
-    u_boot_target = 'pine64-lts'
+    machine: str = 'pine64-lts'
+    flash_kernel_name: str = 'Pine64 LTS'
+    u_boot_target: str = 'pine64-lts'
