@@ -10,7 +10,6 @@ class RaspberryPi3ImageBuilder(RaspberryPiWithUBoot):
     """Image builder for Raspberry Pi 3 target."""
     architecture = 'armhf'
     machine = 'raspberry3'
-    free = False
     kernel_flavor = 'armmp'
     flash_kernel_name = 'Raspberry Pi 3 Model B'
-    uboot_variant = 'rpi_3_32b'
+    u_boot_rpi_variant = 'rpi_3_32b'
