@@ -9,14 +9,15 @@ from .arm import ARMImageBuilder
 
 class RaspberryPiWithUBoot(ARMImageBuilder):
     """Base image builder for Raspberry Pi 2 and 3 targets."""
-    free = False
+    include_non_free_firmware = True
     uboot_variant = None
     firmware_filesystem_type = 'vfat'
-    firmware_size = '64MiB'
+    firmware_size = '256MiB'
+    u_boot_variant = 'rpi'
 
     def install_boot_loader(self, state):
         """Install the boot loader onto the image."""
-        if not self.uboot_variant:
+        if not self.u_boot_rpi_variant:
             raise NotImplementedError
 
         firmware_package = 'raspi-firmware'
@@ -38,7 +39,8 @@ rm -f /boot/firmware/start_*
 
 # u-boot setup
 apt-get install -y u-boot-rpi
-cp /usr/lib/u-boot/{uboot_variant}/u-boot.bin /boot/firmware/kernel.img
-cp /usr/lib/u-boot/{uboot_variant}/u-boot.bin /boot/firmware/kernel7.img
-'''.format(firmware_package=firmware_package, uboot_variant=self.uboot_variant)
+cp /usr/lib/u-boot/{u_boot_rpi_variant}/u-boot.bin /boot/firmware/kernel.img
+cp /usr/lib/u-boot/{u_boot_rpi_variant}/u-boot.bin /boot/firmware/kernel7.img
+'''.format(firmware_package=firmware_package,
+           u_boot_rpi_variant=self.u_boot_rpi_variant)
         library.run_in_chroot(state, ['bash', '-c', script])
