@@ -5,12 +5,22 @@ Base worker class to build Virtual Machine images.
 
 import os
 
+from .. import utils
 from .amd_intel import AMDIntelImageBuilder
 
 
 class VMImageBuilder(AMDIntelImageBuilder):
     """Base image builder for all virtual machine targets."""
-    vm_image_extension = None
+    vm_image_extension: str | None = None
+
+    @property
+    def image_size(self):
+        """Return the additional size for the image for usage."""
+        from ..application import IMAGE_SIZE
+        if self.arguments.image_size == IMAGE_SIZE:
+            return utils.add_disk_sizes(IMAGE_SIZE, '12G')
+
+        return self.arguments.image_size
 
     def build(self):
         """Run the image building process."""
