@@ -42,6 +42,7 @@ class InternalBuilderBackend:
                 self._install_build_dependencies()
             self._remove_ssh_keys()
             self._install_boot_loader()
+            self._extra_setup()
             self._setup_final_apt()
             self._fill_free_space_with_zeros()
         except (Exception, KeyboardInterrupt) as exception:
@@ -381,6 +382,11 @@ class InternalBuilderBackend:
 
         library.update_initramfs(self.state)
 
+    def _extra_setup(self):
+        """Allow builders to run additional setup if needed."""
+        if hasattr(self.builder, 'extra_setup'):
+            self.builder.extra_setup(self.state)
+
     def _setup_build_apt(self):
         """Setup apt to use the build mirror."""
         use_backports = self._should_use_backports()
