@@ -446,11 +446,11 @@ def test_cleanup_extra_storage(run, image, state, random_string):
 @patch('freedommaker.library.run')
 def test_debootstrap(run, state):
     """Test debootstrapping."""
-    library.debootstrap(state, 'i386', 'stretch', 'minbase',
+    library.debootstrap(state, 'amd64', 'stretch', 'minbase',
                         ['main', 'contrib'], ['p1', 'p2'],
                         'http://deb.debian.org/debian')
     run.assert_called_with([
-        'debootstrap', '--arch=i386', '--variant=minbase',
+        'debootstrap', '--arch=amd64', '--variant=minbase',
         '--components=main,contrib', '--include=p1,p2', 'stretch',
         state['mount_point'], 'http://deb.debian.org/debian'
     ])
